<?php

/**
 * FSQL drop-in replacement for MySQL PHP functions.
 *
 * @author Paul Slavic, ZZEE, http://zzee.com
 * Copyright 2010 Paul Slavic.
 * You may use this file freely keeping the above author and copyright statement.
 * 
 * All functions here are direct replacement of PHP native MySQL functions.
 * To avoid conflicts first disable (via php.ini) MySQL PHP extension.
 *
 * FSQL Project home:
 * http://fsql.sourceforge.net/index.html
 * FSQL Download is here:
 * http://sourceforge.net/projects/fsql/
 */

require_once('fSQL.php');

define("MYSQL_ASSOC", 1, true);
define("MYSQL_NUM", 2, true);
define("MYSQL_BOTH", 3, true);

 
/**
 * @param string $server Not used
 * @param string $username Not used
 * @param string $password Not used
 * @param boolean $new_link Not used
 * @param int $client_flags Not used
 * @return object $dbh 
 */
function &mysql_connect($server = '', $username = '', 
	$password ='', $new_link = true, $client_flags = 0) {
    $dbh = new fSQLEnvironment;
    return $dbh;
}


/**
 * @param object $dbh
 * @return boolean
 */
function mysql_close(&$dbh) {
    @$dbh->close();
    return true;
}


/**
 * Difference with native mysql_select_db() is that you need to use
 * path to directory instead of a database name.
 * And database name is always 'mydb'.
 * @param string $pathToFile
 * @param object $dbh
 * @return boolean
 */
function mysql_select_db($pathToDirectory, $dbh) {
    if (!@$dbh->define_db('mydb', $pathToDirectory)) { return false; }
    return @$dbh->select_db('mydb');
}


/**
 * @param string $sql a SQL query
 * @param object $dbh
 * @return For SELECT, SHOW, DESCRIBE or EXPLAIN statements,
 *   mysql_query() returns a resource on success, or FALSE on error.
 *   For other type of SQL statements, UPDATE, DELETE, DROP, etc,
 *   mysql_query() returns TRUE on success or FALSE on error.
 */
function mysql_query($sql, $dbh) {
    $r = @$dbh->query($sql);
    if (!$r) { return false; }
	if (!is_int($r)) { return $r; }
    $res = array();
    $res['r'] = $r;
    $res['dbh'] = &$dbh;
    return $res;
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @param int $result_type The type of array that is to be fetched. 
 *    It's a constant and can take the following values:
 *    MYSQL_ASSOC, MYSQL_NUM, and the default value of MYSQL_BOTH.
 * @return An array that corresponds to the fetched row, 
 *    or FALSE if there are no more rows.
 */
function mysql_fetch_array($result, $result_type = MYSQL_BOTH) {
    if (!is_array($result)) { return false; }
    $dbh = &$result['dbh'];
    $res = @$dbh->fetch_array($result['r'], $result_type);
	if (!$res) { return false; }
	return $res;
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @return An array that corresponds to the fetched row, 
 *    or FALSE if there are no more rows.
 */
function mysql_fetch_assoc($result) {
	return mysql_fetch_array($result, MYSQL_ASSOC);
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @param int $field_offset.
 * @return Object
 * Warning: difference with Mysql. If you don't provide the $field_offset
 * index in mysql_fetch_field() native call it will return the *next* field.
 * Here it returns the first field in this case.
 */
function mysql_fetch_field($result, $field_offset = null) {
	if (!is_array($result)) { return false; }
    $dbh = &$result['dbh'];
    return @$dbh->fetch_field($result['r'], $field_offset);
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @return Object.
 * Warning: difference with Mysql. [, string class_name [, array params]] 
 *   parameters are not supported. 
 */
function mysql_fetch_object($result, $class_name = false, $params = false) {
	if (!is_array($result)) { return false; }
    $dbh = &$result['dbh'];
    return @$dbh->fetch_object($result['r']);
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @return An array that corresponds to the fetched row, 
 *    or FALSE if there are no more rows.
 */
function mysql_fetch_row($result) {
	return @mysql_fetch_array($result, MYSQL_NUM);
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @return boolean
 */
function mysql_free_result(&$result) {
	if (!is_array($result)) { return false; }
    $dbh = &$result['dbh'];
	@$dbh->free_result($result['r']);
	return true;
}


/**
 * @param object $dbh
 * @return int
 */
function mysql_affected_rows($dbh) {
	return @$dbh->affected_rows();
}


function mysql_change_user($user = '', $password = '', $database = '', $dbh = false) {
	// do nothing
	return true;
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @param int $row_number
 * @return boolean
 */
function mysql_data_seek($result, $row_number) {
	if (!is_array($result)) { return false; }
    $dbh = &$result['dbh'];
	return @$dbh->data_seek($result['r'], $row_number);
}


/**
 * @param object $dbh
 * @return string
 */
function mysql_error($dbh) {
	return @$dbh->error();
}


/**
 * @param string $str
 * @return string
 */
function mysql_escape_string($str) {
	return fSQLEnvironment::escape_string($str);
}

function mysql_real_escape_string($str) {
	return fSQLEnvironment::escape_string($str);
}


/**
 * @param object $dbh
 * @return int
 */
function mysql_insert_id($dbh) {
	return @$dbh->insert_id();
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @return int
 */
function mysql_num_fields($result) {
	if (!is_array($result)) { return false; }
    $dbh = &$result['dbh'];
	return @$dbh->num_fields($result['r']);
}


/**
 * @param resource $result This result comes from a call to mysql_query().
 * @return int
 */
function mysql_num_rows($result) {
	if (!is_array($result)) { return false; }
    $dbh = &$result['dbh'];
	return @$dbh->num_rows($result['r']);
}